# MuMoT: Multiscale Modelling Tool

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/DiODeProject/MuMoT/v1.2.2?filepath=docs%2FMuMoTuserManual.ipynb)
[![](https://img.shields.io/pypi/v/mumot.svg)](https://pypi.org/pypi/mumot/)
[![](https://img.shields.io/pypi/pyversions/mumot.svg)](https://pypi.org/pypi/mumot/)
[![](https://img.shields.io/pypi/l/mumot.svg)](https://pypi.org/pypi/mumot/)

![test_and_upload_distribution](https://github.com/DiODeProject/MuMoT/workflows/test_and_upload_distribution/badge.svg?branch=master)
[![Documentation Status](https://readthedocs.org/projects/mumot/badge/?version=latest)](https://mumot.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://codecov.io/github/DiODeProject/MuMoT/coverage.svg?branch=master)](https://codecov.io/gh/DiODeProject/MuMoT)

## Introduction / overview

MuMoT (Multiscale Modelling Tool) is a tool designed to allow sophisticated mathematical modelling and analysis,
without writing equations -
the class of models that can be represented is broad,
ranging from chemical reaction kinetics to
demography and collective behaviour -
by using a web-based interactive interface with minimal coding,
rapid development and exploration of models is facilitated -
the tool may also be particularly useful for pedagogical demonstrations.

## Documentation

See [https://mumot.readthedocs.io](https://mumot.readthedocs.io) for

  * How to **get started** with MuMoT,
    including how to **use MuMoT online** without installing anything on your own machine.
  * **Installation instructions**, should you want to install it on your own machine.
  * **Development**: how to report issues and how to contribute to the project.
  * Information about MuMoT including contributors, acknowledgements, and citation details.
  * API documentation.
